==> bizext.php7.0.zip: bizext/lib/spout/Writer/Exception/InvalidColorException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPxedtI0S3IONRP180m9u6YS6kBtBJfKgAalTX0z5c5xkA1eXD1e97UhlS6Gg641iRmu4XDye
gOPjgOJtH95zSKz9a8gVDaDgz8iVHZ6LWH1Mphu88DZChBk0d8n0MvjbPT0Xr0D29GI9UfDVsOdc
j6qj6E/JFw63szXGtbluihK9jUCsGepJKkHrh0lks11/9vAVJN/e1g5DuOCsps/peygFIcfdevJd
ej+Jv0dpS9sZrwE6JwSaWx2nOrjW530gybQZCooUFo0C6MdPVf6CJO+fz41htjb0nYYvAW6/EIOx
dVqoBG/tmMU5sMh65UGJoL4dj2QaySebaPdwaFsrAOtTkcXCbGRdiTK6W6c7CScwtNTUsp6Yw+81
I1AOX58QWdimFnaA1WVx28l4ZhExfdwjtXMgSxqe6IEf6g0AyAv8dHXFoJIiapsga/c4bhRXmLq5
fW00WQd8P8Z50IMQj7iEhrM81+9wpPSU2H+jrWE7nL2c2fiKJPbp33rCqNYrW91kaXHNX48AEUb8
4kyBTRPM27sVCnog+pR1Cg8v/OTtT2gNBzoZk59KVThW45hKCVOqpkbsDQovld5vAZw4DdD6RvgS
vqQQrQ3GOq6i+ztv70mglsv6Iw7Wh4QDVNxbXcRsSuESQmIGSu5MYwS3KEwr2+6qYvux9jlsyB+7
HuawSpgD48oUE+ULPCblmA5lBczMT7NopKSHp9CrBw98pgo4zIW6HY56mMLGpgQLadkeoNz2fv2f
p19Vb5Wusr8EEe0QzkakdNaQR7234QOlA25RrkKJbY9blgF8+/1+rAjJv3Q2lQqTBrG7ZRaB8w/M
1nyxhkK3irDMPP/G2JJrsaGNAezAIWwtTKJHsBw6RZbHpDSpBKDctwyLDt7iluGI/RW2OKabJ9Ym
8pdTW7L3fo/PM7fJ4zgnnf0h+zxnLE1yyfhVMNvxZ4QACgcngYOkt0KRFeZHnLcGaAiiN4wQk60S
532zWfWg6TKH3lY2ImCv0hZxNQfKuEZPXxAVUGa4GnDjyixKJlfbcAIrz2lD7vi04l4+8HJeUBah
8ZrwBzlqg0S0YBrfOJ+YNBlyeLNkjO+mgivOEj/5mWi9vb4xcDGFZnCQ/sRM7NugHa7L8HKdYRHh
KmH2weV740zq++JAU2/jh+hhFfcwo9S3YDnObavNLEBWlmeBCLpl779b//oDegFYzplccK+EAxPD
8jv8ktixJU4Haey1oUw+j+hp4hja6i0p3FIBCsxUnQmpsDcUPah3eKmsGGdXOaRxYXhwSQlQ7CVD
Of8QQMthyMDM6muU79+LwxdN4sZotq9zQAwI30RZ9RnwiDGQWBZR430wNyzmcKELAwyelNgLoGmT
ydjl+J2utQbrXeSgW2MhC/MZpTUEHIHajQwYCzrzfWMl8p3lbJCGTsqJQvbCaerqjYS5W0m8P+qD
SxRj6MpzasdOfswRRpCO49i2gbVsEjyB20vwEgFCPYjsItVQD6FOh/s5s/4=

==> bizext.php7.1.zip: bizext/lib/spout/Writer/Exception/InvalidColorException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPqyZxg2v2jENy9PxWoaMePBkdl4LG9hfbWLs/bAL20UO3yah+NaxLSCGR+dJoSsBhY7bKeRj
KdToJF59WYiWhxBPTJaYMWNUJX7uRDCiD3h17KnBL8Jf9pyVMr9vuojYfapxbaIZbhHEwi948AKl
1a5MCtVCQuTUIE0ZN7PUvL1qxFCGo7ZJtDkc6svJOE5HFa2gmG0Y7O4gfif10XuNsOIoK93gPjza
tX9c3myQQBZOS585ZL0U1OOP7z5KY69yf+cthjv/dcvvu1Kq4Vn5sZ+JOCOmpH2S5SKq8Kg1vDTM
bTMARx+Js/zHkUsEroop63K7a0DAgWchnAjNwIUUAL6pSnlKtw1b0qYrxRrnauOGYCsBKS9v9DnB
805vr2MSqZBGh9VmY4VL4uwrw+6yXnm52+gHXGxB36k1Pi+0fPvS2FSknWwIlc/HOQRqgLaKWCxP
KLX0zMMVskn9S6FMJaAKQrpIQZf6CoIbfIO94HhGk2DjYfvQf3gFbSsZSEmkcsunZPVU02cuR+tt
thpWm1l+M9P2ImWnMpQpZuP4RTJCzleO+KnxvjrA/dLSSRcrtxxGW0sJu28uX0EsYsa11Ho5JY41
WKbBTn+OI5scu9RmNjJ+Oeahb85WPH1hbxFwG2mlLozSfJEu89L058xjDZ9gd51HYPTbOTDkkX7S
Lp0cPWQYP5DXwBa5L1gjUHHh+0si1O7XtgTS1XFaEg8mhhln3Jw54d//Fug9ma1lxLRLW7JtLToE
UN0C9OtMVArPPdNG6kwcva4xVSD0uokkUImtQvI/Of2Myf79S6W6Y4TtKU8pZ+lopENKONh1KFDD
S9lTH/twyNDhHlMnCla8lhIcfIYjRRDwuH4drKM8NmCuUwVAQxYCtQhmlSHkUPATB4DOJri9GECX
mEgIgvleNJ7HQp/epEEXhR/kY0==
